@@ -46,6 +46,8 @@ pub type NameToolchainMap = BTreeMap<String, ToolchainMap>;
 #[derive(Debug, Default)]
 pub struct Dylint {
     pub all: bool,
+    pub fix: bool,
+    pub force: bool,
     pub isolate: bool,
     pub keep_going: bool,
     pub libs: Vec<String>,
@@ -65,6 +67,10 @@ pub struct Dylint {
 }
 
 pub fn run(opts: &Dylint) -> Result<()> {
+    if opts.force && opts.upgrade_path.is_none() {
+        bail!("`--force` can be used only with `--upgrade`");
+    }
+
     if opts.isolate && opts.new_path.is_none() {
         bail!("`--isolate` can be used only with `--new`");
     }
@@ -192,7 +198,7 @@ fn run_with_name_toolchain_map(opts: &Dylint, name_toolchain_map: &NameToolchain
     if opts.list {
         list_lints(opts, name_toolchain_map, &resolved)
     } else {
-        check(opts, name_toolchain_map, &resolved)
+        check_or_fix(opts, name_toolchain_map, &resolved)
     }
 }
 
@@ -422,7 +428,7 @@ fn list_lints(
     Ok(())
 }
 
-fn check(
+fn check_or_fix(
     opts: &Dylint,
     _name_toolchain_map: &NameToolchainMap,
     resolved: &ToolchainMap,
@@ -436,6 +442,11 @@ fn check(
         let target_dir_str = target_dir.to_string_lossy();
         let driver = driver_builder::get(opts, toolchain)?;
         let dylint_libs = serde_json::to_string(&paths)?;
+        let mut command = if opts.fix {
+            dylint_internal::fix()
+        } else {
+            dylint_internal::check()
+        };
         let mut args = vec!["--target-dir", &target_dir_str];
         if let Some(path) = &opts.manifest_path {
             args.extend(&["--manifest-path", path]);
@@ -456,7 +467,7 @@ fn check(
         // https://github.com/rust-lang/rust-clippy/commit/1a206fc4abae0b57a3f393481367cf3efca23586
         // But I am going to continue to set CLIPPY_DISABLE_DOCS_LINKS because it doesn't seem to
         // hurt and it provides a small amount of backward compatibility.
-        let result = dylint_internal::check()
+        let result = command
             .envs(vec![
                 (
                     env::CLIPPY_DISABLE_DOCS_LINKS.to_owned(),
